#ifndef _BUMP_ALLOC
#define _BUMP_ALLOC

#include "Types.h"

typedef void* BumpArena;

BumpArena Bcreate(usize size);
Result    Bdestroy(BumpArena b);

void*  Balloc(BumpArena b, usize size);
int    Bresizeable(BumpArena b, void* ptr);
Result Bresize(BumpArena b, usize size);
Result Bfree(BumpArena b);

#endif /* _BUMP_ALLOC */
