#ifndef _GLOBAL_ARENA
#define _GLOBAL_ARENA

#include "BumpAlloc.h"
#include "Array.h"

// Global bump arena
extern BumpArena g_arena;

void*  GBalloc(usize size);
int    GBresizeable(void* ptr);
Result GBresize(usize size);
Result GBfree();

Array Array_Gnew(usize element_size, usize length);

#endif /* _GLOBAL_ARENA */
