#include "GlobalArena.h"

BumpArena g_arena = NULL;

void*
GBalloc(usize size) {
    return Balloc(g_arena, size);
}

int
GBresizeable(void* ptr) {
    return Bresizeable(g_arena, ptr);
}

Result
GBresize(usize size) {
    return Bresize(g_arena, size);
}

Result
GBfree() {
    return Bfree(g_arena);
}

Array
Array_Gnew(usize element_size, usize length) {
    return Array_new(g_arena, element_size, length);
}
