#ifndef _ARRAY
#define _ARRAY

#include "Types.h"
#include "BumpAlloc.h"

typedef void* Array;

Array  Array_new(BumpArena b, usize element_size, usize length);
usize  Array_length(Array arr);
usize  Array_count(Array arr);
Result Array_push(Array arr, void *value);
void*  Array_pop(Array arr);

#endif /* _ARRAY */
